@@ -57,3 +57,31 @@ class SanlockInitializationError(Exception):
 
 class BrokerInitializationError(Exception):
     pass
+
+
+class DuplicateStorageConnectionException(Exception):
+    """
+    This exception is raised when a potentially duplicate storage connection
+    has been detected on a wrong path: see rhbz#1300749
+
+    The agent should exits disconnecting the storage server.
+    Systemd will restart the agent if needed.
+    """
+
+
+class StorageDisconnectedError(Exception):
+    """
+    This exceptions is raised when storage domain is in invalid state.
+
+    The agent should exit.
+    Systemd will restart the agent if needed.
+    """
+
+
+class HostIdNotLockedError(Exception):
+    """
+    This exception is raised when host id is not set and locked.
+
+    The agent should exit.
+    Systemd will restart the agent if needed.
+    """
